==> openshift-client-4.13.0-sources.jar: io/fabric8/openshift/client/dsl/internal/ImagePrunerOperationsImpl.java <==

                
  

package io.fabric8.openshift.client.dsl.internal;

import io.fabric8.openshift.client.OpenShiftConfig;
import io.fabric8.kubernetes.client.dsl.Resource;
import io.fabric8.kubernetes.client.dsl.base.HasMetadataOperation;
import io.fabric8.kubernetes.client.dsl.NonNamespaceOperation;
import io.fabric8.kubernetes.client.utils.ApiVersionUtil;
import io.fabric8.kubernetes.client.dsl.base.OperationContext;
import io.fabric8.openshift.client.OpenShiftConfig;

import okhttp3.OkHttpClient;

import io.fabric8.openshift.api.model.operator.v1.DoneableImagePruner;
import io.fabric8.openshift.api.model.operator.v1.ImagePruner;
import io.fabric8.openshift.api.model.operator.v1.ImagePrunerList;
import io.fabric8.openshift.api.model.operator.v1.DoneableImagePruner;

import java.util.Map;
import java.util.TreeMap;


public class ImagePrunerOperationsImpl extends OpenShiftOperation<ImagePruner, ImagePrunerList, DoneableImagePruner, Resource<ImagePruner, DoneableImagePruner>> {

  public ImagePrunerOperationsImpl(OkHttpClient client, OpenShiftConfig config) {
    this(new OperationContext().withOkhttpClient(client).withConfig(config).withPropagationPolicy(DEFAULT_PROPAGATION_POLICY));
  }

  public ImagePrunerOperationsImpl(OperationContext context) {
    super(context.withApiGroupName("imageregistry.operator.openshift.io")
    .withApiGroupVersion("v1")
    .withPlural("imagepruners"));
    this.type = ImagePruner.class;
    this.listType = ImagePrunerList.class;
    this.doneableType = DoneableImagePruner.class;
  }

  public ImagePrunerOperationsImpl newInstance(OperationContext context) {
    return new ImagePrunerOperationsImpl(context);
  }
  
  @Override
  public boolean isResourceNamespaced() {
    return false;
  }
}

==> openshift-client-5.0.1-sources.jar: io/fabric8/openshift/client/dsl/internal/ImagePrunerOperationsImpl.java <==

                            
  

package io.fabric8.openshift.client.dsl.internal;

import io.fabric8.kubernetes.api.builder.Visitor;
import io.fabric8.openshift.client.OpenShiftConfig;
import io.fabric8.kubernetes.client.dsl.Resource;
import io.fabric8.kubernetes.client.dsl.base.HasMetadataOperation;
import io.fabric8.kubernetes.client.dsl.NonNamespaceOperation;
import io.fabric8.kubernetes.client.utils.ApiVersionUtil;
import io.fabric8.kubernetes.client.dsl.base.OperationContext;
import io.fabric8.openshift.client.OpenShiftConfig;

import okhttp3.OkHttpClient;

import io.fabric8.openshift.api.model.operator.v1.ImagePruner;
import io.fabric8.openshift.api.model.operator.v1.ImagePrunerBuilder;
import io.fabric8.openshift.api.model.operator.v1.ImagePrunerList;

import java.util.Map;
import java.util.TreeMap;


public class ImagePrunerOperationsImpl extends OpenShiftOperation<ImagePruner, ImagePrunerList, Resource<ImagePruner>> {

  public ImagePrunerOperationsImpl(OkHttpClient client, OpenShiftConfig config) {
    this(new OperationContext().withOkhttpClient(client).withConfig(config).withPropagationPolicy(DEFAULT_PROPAGATION_POLICY));
  }

  public ImagePrunerOperationsImpl(OperationContext context) {
    super(context.withApiGroupName("imageregistry.operator.openshift.io")
    .withApiGroupVersion("v1")
    .withPlural("imagepruners"));
    this.type = ImagePruner.class;
    this.listType = ImagePrunerList.class;
  }

  public ImagePrunerOperationsImpl newInstance(OperationContext context) {
    return new ImagePrunerOperationsImpl(context);
  }

  @Override
  public ImagePruner edit(Visitor... visitors) {
    return patch(new ImagePrunerBuilder(getMandatory()).accept(visitors).build());
  }
 
  @Override
  public boolean isResourceNamespaced() {
    return false;
  }
}
